@@ -1,7 +1,7 @@
 package Complete::Getopt::Long;
 
-our $DATE = '2015-09-22'; # DATE
-our $VERSION = '0.37'; # VERSION
+our $DATE = '2016-01-07'; # DATE
+our $VERSION = '0.39'; # VERSION
 
 use 5.010001;
 use strict;
@@ -471,6 +471,7 @@ sub complete_cli_arg {
 
     # complete option names
     {
+        last if $word =~ /\A[^-]/;
         last unless exists $exp->{optname};
         last if defined($exp->{do_complete_optname}) &&
             !$exp->{do_complete_optname};
@@ -587,7 +588,7 @@ Complete::Getopt::Long - Complete command-line argument using Getopt::Long speci
 
 =head1 VERSION
 
-This document describes version 0.37 of Complete::Getopt::Long (from Perl distribution Complete-Getopt-Long), released on 2015-09-22.
+This document describes version 0.39 of Complete::Getopt::Long (from Perl distribution Complete-Getopt-Long), released on 2016-01-07.
 
 =head1 SYNOPSIS
 
@@ -617,6 +618,8 @@ sensible default. This routine also does not currently support C<auto_help> and
 C<auto_version>, so you'll need to add those options specifically if you want to
 recognize C<--help/-?> and C<--version>, respectively.
 
+This function is not exported by default, but exportable.
+
 Arguments ('*' denotes required arguments):
 
 =over 4
@@ -769,7 +772,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by perlancar@cpan.org.
+This software is copyright (c) 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
